@@ -22,7 +22,9 @@ warnings.formatwarning = warning_on_one_line  # type: ignore
 class StoichiometricMixin(CompoundMixin, BaseModel):
     """Mixin for stoichiometries."""
 
-    def __init__(self, rate_stoichiometries: dict[str, dict[str, float]] | None = None) -> None:
+    def __init__(
+        self, rate_stoichiometries: dict[str, dict[str, float]] | None = None
+    ) -> None:
         self.stoichiometries: Dict[str, Dict[str, float]] = {}
         self.stoichiometries_by_compounds: Dict[str, Dict[str, float]] = {}
         if rate_stoichiometries is not None:
@@ -50,7 +52,9 @@ class StoichiometricMixin(CompoundMixin, BaseModel):
         for compound, factor in stoichiometry.items():
             self.stoichiometries_by_compounds.setdefault(compound, {})[rate_name] = factor
 
-    def add_stoichiometry_by_compound(self, compound: str, stoichiometry: Dict[str, float]) -> None:
+    def add_stoichiometry_by_compound(
+        self, compound: str, stoichiometry: Dict[str, float]
+    ) -> None:
         """Add the stoichiometry of compound to the model.
 
         Examples
@@ -66,7 +70,9 @@ class StoichiometricMixin(CompoundMixin, BaseModel):
         for rate, factor in stoichiometry.items():
             self.stoichiometries.setdefault(rate, {})[compound] = factor
 
-    def add_stoichiometries(self, rate_stoichiometries: Dict[str, Dict[str, float]]) -> None:
+    def add_stoichiometries(
+        self, rate_stoichiometries: Dict[str, Dict[str, float]]
+    ) -> None:
         """Add the stoichiometry of multiple rates.
 
         Examples
@@ -81,7 +87,9 @@ class StoichiometricMixin(CompoundMixin, BaseModel):
         for rate_name, stoichiometry in rate_stoichiometries.items():
             self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
-    def update_stoichiometry(self, rate_name: str, stoichiometry: Dict[str, float]) -> None:
+    def update_stoichiometry(
+        self, rate_name: str, stoichiometry: Dict[str, float]
+    ) -> None:
         """Update stoichiometry of a rate"""
         if rate_name not in self.stoichiometries:
             warnings.warn("Rate not in stoichiometries!")
@@ -89,12 +97,16 @@ class StoichiometricMixin(CompoundMixin, BaseModel):
             self.remove_rate_stoichiometry(rate_name)
         self.add_stoichiometry(rate_name, stoichiometry)
 
-    def update_stoichiometries(self, stoichiometries: Dict[str, Dict[str, float]]) -> None:
+    def update_stoichiometries(
+        self, stoichiometries: Dict[str, Dict[str, float]]
+    ) -> None:
         """Update stoichiometries of multiple rates"""
         for rate_name, stoichiometry in stoichiometries.items():
             self.update_stoichiometry(rate_name, stoichiometry)
 
-    def add_stoichiometries_by_compounds(self, compound_stoichiometries: Dict[str, Dict[str, float]]) -> None:
+    def add_stoichiometries_by_compounds(
+        self, compound_stoichiometries: Dict[str, Dict[str, float]]
+    ) -> None:
         """Add the stoichiometry of multiple compounds to the model.
 
         Examples
@@ -107,7 +119,9 @@ class StoichiometricMixin(CompoundMixin, BaseModel):
         )
         """
         for compound, stoichiometry in compound_stoichiometries.items():
-            self.add_stoichiometry_by_compound(compound=compound, stoichiometry=stoichiometry)
+            self.add_stoichiometry_by_compound(
+                compound=compound, stoichiometry=stoichiometry
+            )
 
     def remove_rate_stoichiometry(self, rate_name: str) -> None:
         """Remove a rate stoichiometry from the model."""
