@@ -59,7 +59,7 @@ class Model(_AbstractRateModel, BaseModel):
         StoichiometricMixin.__init__(self, rate_stoichiometries=rate_stoichiometries)
         RateMixin.__init__(self, rates=rates, functions=functions)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
-        self.derived_stoichiometries: Dict[str, DerivedStoichiometry] = {}
+        self.derived_stoichiometries: Dict[str, Dict[str, DerivedStoichiometry]] = {}
 
     def __enter__(self) -> "Model":
         """Enter the context manager.
@@ -237,17 +237,32 @@ class Model(_AbstractRateModel, BaseModel):
     # Reactions
     ##########################################################################
 
-    # def add_derived_stoichiometry(
-    #     self, name: str, function: Callable, args: list[str]
-    # ) -> None:
-    #     raise NotImplementedError
+    def _add_derived_stoichiometry(
+        self, rate_name: str, cpd_name: str, derived_stoichiometry: DerivedStoichiometry
+    ) -> None:
+        self.derived_stoichiometries.setdefault(rate_name, {})[
+            cpd_name
+        ] = derived_stoichiometry
+        self._update_derived_stoichiometries()
 
-    # def _update_derived_stoichiometries(self) -> None:
-    #     for name, stoichiometry in self.derived_stoichiometries.items():
-    #         factor = stoichiometry.function(
-    #             *(self.parameters[i] for i in stoichiometry.args)
-    #         )
-    #         self.update_stoichiometry(name, factor)
+    def _update_derived_stoichiometries(self) -> None:
+        for rate_name, d in self.derived_stoichiometries.items():
+            for cpd_name, stoichiometry in d.items():
+                self.stoichiometries[rate_name].update(
+                    {
+                        cpd_name: stoichiometry.function(
+                            *(self.parameters[i] for i in stoichiometry.args)
+                        )
+                    }
+                )
+
+    def update_parameter(self, parameter_name: str, parameter_value: float) -> None:
+        super().update_parameter(parameter_name, parameter_value)
+        self._update_derived_stoichiometries()
+
+    def update_parameters(self, parameters: Dict[str, float]) -> None:
+        super().update_parameters(parameters)
+        self._update_derived_stoichiometries()
 
     def add_reaction(
         self,
@@ -260,6 +275,7 @@ class Model(_AbstractRateModel, BaseModel):
         args: List[str] | None = None,
         reversible: bool = False,
         check_consistency: bool = True,
+        derived_stoichiometry: Dict[str, DerivedStoichiometry] | None = None,
         **meta_info: Dict[str, Any],
     ) -> None:
         """Add a reaction to the model.
@@ -288,6 +304,14 @@ class Model(_AbstractRateModel, BaseModel):
         >>>     reversible=True,
         >>> )
         """
+        self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
+
+        if derived_stoichiometry is not None:
+            for cpd_name, der in derived_stoichiometry.items():
+                self._add_derived_stoichiometry(rate_name, cpd_name, der)
+
+        # Use now updated stoichiometry
+        stoichiometry = self.stoichiometries[rate_name]
         substrates = [k for k, v in stoichiometry.items() if v < 0]
         products = [k for k, v in stoichiometry.items() if v > 0]
 
@@ -304,7 +328,6 @@ class Model(_AbstractRateModel, BaseModel):
             check_consistency=check_consistency,
             **meta_info,
         )
-        self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
     def add_reaction_from_args(
         self,
@@ -313,7 +336,17 @@ class Model(_AbstractRateModel, BaseModel):
         stoichiometry: Dict[str, float],
         args: List[str],
         reversible: bool | None = None,
+        derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
     ) -> None:
+        self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
+
+        if derived_stoichiometry is not None:
+            for cpd_name, der in derived_stoichiometry.items():
+                self._add_derived_stoichiometry(rate_name, cpd_name, der)
+
+        # Use now updated stoichiometry
+        stoichiometry = self.stoichiometries[rate_name]
+
         modifiers = []
         parameters = []
         dynamic_variables = []
@@ -345,7 +378,6 @@ class Model(_AbstractRateModel, BaseModel):
             args=args,
             reversible=reversible,
         )
-        self.add_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
     def update_reaction(
         self,
@@ -358,6 +390,7 @@ class Model(_AbstractRateModel, BaseModel):
         args: List[str] | None = None,
         reversible: bool | None = None,
         check_consistency: bool = True,
+        derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
     ) -> None:
         """Update an existing reaction.
 
@@ -367,7 +400,15 @@ class Model(_AbstractRateModel, BaseModel):
         update_rate
         update_stoichiometry
         """
+        if derived_stoichiometry is not None:
+            for cpd_name, der in derived_stoichiometry.items():
+                self._add_derived_stoichiometry(rate_name, cpd_name, der)
+
         if stoichiometry is not None:
+            self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
+
+        if stoichiometry is not None:
+            stoichiometry = self.stoichiometries[rate_name]
             substrates = [k for k, v in stoichiometry.items() if v < 0]
             products = [k for k, v in stoichiometry.items() if v > 0]
         else:
@@ -385,8 +426,6 @@ class Model(_AbstractRateModel, BaseModel):
             args=args,
             check_consistency=check_consistency,
         )
-        if stoichiometry is not None:
-            self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
     def update_reactions(self, reactions: dict) -> None:
         for rate_name, reaction in reactions.items():
@@ -400,12 +439,18 @@ class Model(_AbstractRateModel, BaseModel):
         args: List[str] | None = None,
         reversible: bool | None = None,
         check_consistency: bool = True,
+        derived_stoichiometry: dict[str, DerivedStoichiometry] | None = None,
     ) -> None:
-        if stoichiometry is None:
-            stoichiometry = self.stoichiometries[rate_name]
-        else:
+        if stoichiometry is not None:
             self.update_stoichiometry(rate_name=rate_name, stoichiometry=stoichiometry)
 
+        if derived_stoichiometry is not None:
+            for cpd_name, der in derived_stoichiometry.items():
+                self._add_derived_stoichiometry(rate_name, cpd_name, der)
+
+        # Now properly updated
+        stoichiometry = self.stoichiometries[rate_name]
+
         if function is None:
             function = self.rates[rate_name].function
 
