@@ -6,8 +6,9 @@ import numpy as np
 from matplotlib.axes import Axes as plt_axes
 from matplotlib.figure import Figure as plt_figure
 from numpy.typing import NDArray
+from typing_extensions import TypeAlias
 
-Array = NDArray[np.float64]
+Array: TypeAlias = NDArray[np.float64]
 Number = Union[
     float,
     List[float],
